package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.canteen.core.menu.domain.MenuRecipeDetail;
import com.bonus.canteen.core.menu.service.IMenuRecipeDetailService;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 菜品计划详情信息Controller
 * 
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "菜品计划详情信息接口")
@RestController
@RequestMapping("/menu_recipe_detail")
public class MenuRecipeDetailController extends BaseController {
    @Autowired
    private IMenuRecipeDetailService menuRecipeDetailService;

    /**
     * 查询菜品计划详情信息列表
     */
    @ApiOperation(value = "查询菜品计划详情信息列表")
    //@RequiresPermissions("menu:detail:list")
    @GetMapping("/list")
    public TableDataInfo list(MenuRecipeDetail menuRecipeDetail) {
        startPage();
        List<MenuRecipeDetail> list = menuRecipeDetailService.selectMenuRecipeDetailList(menuRecipeDetail);
        return getDataTable(list);
    }

    /**
     * 导出菜品计划详情信息列表
     */
    @ApiOperation(value = "导出菜品计划详情信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:detail:export")
    @SysLog(title = "菜品计划详情信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出菜品计划详情信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuRecipeDetail menuRecipeDetail) {
        List<MenuRecipeDetail> list = menuRecipeDetailService.selectMenuRecipeDetailList(menuRecipeDetail);
        ExcelUtil<MenuRecipeDetail> util = new ExcelUtil<MenuRecipeDetail>(MenuRecipeDetail.class);
        util.exportExcel(response, list, "菜品计划详情信息数据");
    }

    /**
     * 获取菜品计划详情信息详细信息
     */
    @ApiOperation(value = "获取菜品计划详情信息详细信息")
    //@RequiresPermissions("menu:detail:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(menuRecipeDetailService.selectMenuRecipeDetailById(id));
    }

    /**
     * 新增菜品计划详情信息
     */
    @ApiOperation(value = "新增菜品计划详情信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:detail:add")
    @SysLog(title = "菜品计划详情信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增菜品计划详情信息")
    @PostMapping
    public AjaxResult add(@RequestBody MenuRecipeDetail menuRecipeDetail) {
        try {
            return toAjax(menuRecipeDetailService.insertMenuRecipeDetail(menuRecipeDetail));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改菜品计划详情信息
     */
    @ApiOperation(value = "修改菜品计划详情信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:detail:edit")
    @SysLog(title = "菜品计划详情信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改菜品计划详情信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuRecipeDetail menuRecipeDetail) {
        try {
            return toAjax(menuRecipeDetailService.updateMenuRecipeDetail(menuRecipeDetail));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除菜品计划详情信息
     */
    @ApiOperation(value = "删除菜品计划详情信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:detail:remove")
    @SysLog(title = "菜品计划详情信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除菜品计划详情信息")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(menuRecipeDetailService.deleteMenuRecipeDetailByIds(ids));
    }
}
